aboutsummaryrefslogtreecommitdiff
path: root/engines/tsage
diff options
context:
space:
mode:
authorMax Horn2011-04-14 14:34:28 +0200
committerMax Horn2011-04-14 14:34:28 +0200
commit2e095e25f2435f0d066d2826176e394bda5c4a9c (patch)
tree81d2c4d9e26e4a7644087a13c61b785ae3e431c8 /engines/tsage
parent84184aabc00251374a181fe296487619afa779ed (diff)
downloadscummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.tar.gz
scummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.tar.bz2
scummvm-rg350-2e095e25f2435f0d066d2826176e394bda5c4a9c.zip
ALL: centre -> center
Diffstat (limited to 'engines/tsage')
-rw-r--r--engines/tsage/converse.cpp8
-rw-r--r--engines/tsage/core.cpp10
-rw-r--r--engines/tsage/dialogs.cpp10
-rw-r--r--engines/tsage/globals.cpp4
-rw-r--r--engines/tsage/globals.h2
-rw-r--r--engines/tsage/graphics.cpp24
-rw-r--r--engines/tsage/graphics.h10
-rw-r--r--engines/tsage/ringworld_logic.cpp34
-rw-r--r--engines/tsage/ringworld_scenes1.cpp4
-rw-r--r--engines/tsage/ringworld_scenes10.cpp8
-rw-r--r--engines/tsage/ringworld_scenes2.cpp8
-rw-r--r--engines/tsage/ringworld_scenes3.cpp8
-rw-r--r--engines/tsage/ringworld_scenes5.cpp4
-rw-r--r--engines/tsage/ringworld_scenes6.cpp4
-rw-r--r--engines/tsage/ringworld_scenes8.cpp6
-rw-r--r--engines/tsage/tsage.h4
16 files changed, 74 insertions, 74 deletions
diff --git a/engines/tsage/converse.cpp b/engines/tsage/converse.cpp
index aea195a5ac..86a4bf1461 100644
--- a/engines/tsage/converse.cpp
+++ b/engines/tsage/converse.cpp
@@ -871,7 +871,7 @@ void Speaker::removeText() {
SpeakerGameText::SpeakerGameText() : Speaker() {
_speakerName = "GAMETEXT";
_textPos = Common::Point(40, 40);
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 7;
_textWidth = 230;
_hideObjects = false;
@@ -881,7 +881,7 @@ SpeakerGameText::SpeakerGameText() : Speaker() {
ScreenSpeaker::ScreenSpeaker() : Speaker() {
_npc = NULL;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void ScreenSpeaker::setText(const Common::String &msg) {
@@ -892,9 +892,9 @@ void ScreenSpeaker::setText(const Common::String &msg) {
_globals->gfxManager().getStringBounds(msg.c_str(), textRect, _textWidth);
if (_npc) {
- textRect.centre(_npc->_position.x, _npc->_bounds.top - (textRect.height() / 2 + 10));
+ textRect.center(_npc->_position.x, _npc->_bounds.top - (textRect.height() / 2 + 10));
} else {
- textRect.centre(_globals->_sceneManager._scene->_sceneBounds.left +
+ textRect.center(_globals->_sceneManager._scene->_sceneBounds.left +
(_globals->_sceneManager._scene->_sceneBounds.width() / 2),
_globals->_sceneManager._scene->_sceneBounds.top);
}
diff --git a/engines/tsage/core.cpp b/engines/tsage/core.cpp
index 818f8b7b5c..2e3f99ec19 100644
--- a/engines/tsage/core.cpp
+++ b/engines/tsage/core.cpp
@@ -1496,7 +1496,7 @@ void SceneItem::display(int resNum, int lineNum, ...) {
Rect textRect;
int maxWidth = 120;
bool keepOnscreen = false;
- bool centreText = true;
+ bool centerText = true;
if (resNum) {
va_list va;
@@ -1559,7 +1559,7 @@ void SceneItem::display(int resNum, int lineNum, ...) {
}
case SET_POS_MODE:
// Set whether a custom x/y is used
- centreText = va_arg(va, int) != 0;
+ centerText = va_arg(va, int) != 0;
break;
case SET_TEXT_MODE:
// Set the text mode
@@ -1576,17 +1576,17 @@ void SceneItem::display(int resNum, int lineNum, ...) {
if (resNum) {
// Get required bounding size
_globals->gfxManager().getStringBounds(msg.c_str(), textRect, maxWidth);
- textRect.centre(pos.x, pos.y);
+ textRect.center(pos.x, pos.y);
textRect.contain(_globals->gfxManager()._bounds);
- if (centreText) {
+ if (centerText) {
_globals->_sceneText._color1 = _globals->_sceneText._color2;
_globals->_sceneText._color2 = 0;
_globals->_sceneText._color3 = 0;
}
_globals->_sceneText.setup(msg);
- if (centreText) {
+ if (centerText) {
_globals->_sceneText.setPosition(Common::Point(
_globals->_sceneManager._scene->_sceneBounds.left + textRect.left,
_globals->_sceneManager._scene->_sceneBounds.top + textRect.top), 0);
diff --git a/engines/tsage/globals.cpp b/engines/tsage/globals.cpp
index fc764172f5..7f41ab0978 100644
--- a/engines/tsage/globals.cpp
+++ b/engines/tsage/globals.cpp
@@ -47,7 +47,7 @@ static SavedObject *classFactoryProc(const Common::String &className) {
/*--------------------------------------------------------------------------*/
Globals::Globals() :
- _dialogCentre(160, 140),
+ _dialogCenter(160, 140),
_gfxManagerInstance(_screenSurface) {
reset();
_stripNum = 0;
@@ -89,7 +89,7 @@ void Globals::synchronise(Serialiser &s) {
s.syncAsSint32LE(_fontColors.background);
s.syncAsSint32LE(_fontColors.foreground);
- s.syncAsSint16LE(_dialogCentre.x); s.syncAsSint16LE(_dialogCentre.y);
+ s.syncAsSint16LE(_dialogCenter.x); s.syncAsSint16LE(_dialogCenter.y);
_sceneListeners.synchronise(s);
for (int i = 0; i < 256; ++i)
s.syncAsByte(_flags[i]);
diff --git a/engines/tsage/globals.h b/engines/tsage/globals.h
index bd60d25bf8..6fe8e6295a 100644
--- a/engines/tsage/globals.h
+++ b/engines/tsage/globals.h
@@ -55,7 +55,7 @@ public:
GfxColors _gfxColors;
GfxColors _fontColors;
SoundManager _soundManager;
- Common::Point _dialogCentre;
+ Common::Point _dialogCenter;
WalkRegions _walkRegions;
SynchronisedList<EventHandler *> _sceneListeners;
bool _flags[256];
diff --git a/engines/tsage/graphics.h b/engines/tsage/graphics.h
index b4ae20227e..c266d74bc5 100644
--- a/engines/tsage/graphics.h
+++ b/engines/tsage/graphics.h
@@ -48,9 +48,9 @@ public:
void set(int16 x1, int16 y1, int16 x2, int16 y2);
void collapse(int dx, int dy);
- void centre(int dx, int dy);
- void centre(const Rect &r);
- void centre(const Common::Point &pt) { centre(pt.x, pt.y); }
+ void center(int dx, int dy);
+ void center(const Rect &r);
+ void center(const Common::Point &pt) { center(pt.x, pt.y); }
void contain(const Rect &r);
void resize(const GfxSurface &surface, int xp, int yp, int percent);
void expandPanes();
@@ -115,7 +115,7 @@ public:
static bool displayText(const Common::String &msg, const Common::Point &pt = Common::Point(160, 100));
};
-enum TextAlign {ALIGN_LEFT = 0, ALIGN_CENTRE = 1, ALIGN_RIGHT = 2, ALIGN_JUSTIFIED = 3};
+enum TextAlign {ALIGN_LEFT = 0, ALIGN_CENTER = 1, ALIGN_RIGHT = 2, ALIGN_JUSTIFIED = 3};
class GfxFont {
friend class GfxFontBackup;
@@ -325,7 +325,7 @@ public:
void add(GfxElement *element);
void addElements(GfxElement *ge, ...);
void setTopLeft(int xp, int yp);
- void setCentre(int xp, int yp);
+ void setCenter(int xp, int yp);
void frame() {
setDefaults();
_bounds.collapse(6, 6);
diff --git a/engines/tsage/ringworld_logic.cpp b/engines/tsage/ringworld_logic.cpp
index ac92134393..9286521a29 100644
--- a/engines/tsage/ringworld_logic.cpp
+++ b/engines/tsage/ringworld_logic.cpp
@@ -331,7 +331,7 @@ void SpeakerGText::setText(const Common::String &msg) {
// Set the text
Rect textRect;
_globals->gfxManager()._font.getStringBounds(msg.c_str(), textRect, _textWidth);
- textRect.centre(_sceneObject._position.x, _sceneObject._position.y);
+ textRect.center(_sceneObject._position.x, _sceneObject._position.y);
_textPos.x = textRect.left;
Speaker::setText(msg);
}
@@ -438,7 +438,7 @@ SpeakerQText::SpeakerQText() : ScreenSpeaker() {
_textPos = Common::Point(160, 40);
_color1 = 35;
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_hideObjects = false;
}
@@ -448,7 +448,7 @@ SpeakerSText::SpeakerSText() : ScreenSpeaker() {
_speakerName = "STEXT";
_color1 = 13;
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_hideObjects = false;
}
@@ -457,7 +457,7 @@ SpeakerSText::SpeakerSText() : ScreenSpeaker() {
SpeakerPOText::SpeakerPOText() : ScreenSpeaker() {
_speakerName = "POTEXT";
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 41;
_hideObjects = false;
}
@@ -468,7 +468,7 @@ SpeakerMText::SpeakerMText() {
_speakerName = "MTEXT";
_color1 = 11;
_textWidth = 160;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_hideObjects = false;
}
@@ -478,7 +478,7 @@ SpeakerCText::SpeakerCText() {
_speakerName = "CTEXT";
_color1 = 4;
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_hideObjects = false;
}
@@ -515,7 +515,7 @@ SpeakerHText::SpeakerHText() {
SpeakerSKText::SpeakerSKText() : ScreenSpeaker() {
_speakerName = "SKTEXT";
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 5;
_hideObjects = false;
}
@@ -525,7 +525,7 @@ SpeakerSKText::SpeakerSKText() : ScreenSpeaker() {
SpeakerPText::SpeakerPText() {
_speakerName = "PTEXT";
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 5;
_hideObjects = false;
}
@@ -535,7 +535,7 @@ SpeakerPText::SpeakerPText() {
SpeakerCHFText::SpeakerCHFText() {
_speakerName = "CHFTEXT";
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 56;
_hideObjects = false;
}
@@ -545,7 +545,7 @@ SpeakerCHFText::SpeakerCHFText() {
SpeakerCDRText::SpeakerCDRText() {
_speakerName = "CDRTEXT";
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 52;
_hideObjects = false;
}
@@ -564,7 +564,7 @@ SpeakerFLText::SpeakerFLText() {
SpeakerBatText::SpeakerBatText() {
_speakerName = "BATTEXT";
_textWidth = 240;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
_color1 = 3;
_hideObjects = false;
}
@@ -607,7 +607,7 @@ SpeakerQL::SpeakerQL() : AnimatedSpeaker() {
_newSceneNumber = 2610;
_textPos = Common::Point(160, 30);
_color1 = 35;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void SpeakerQL::setText(const Common::String &msg) {
@@ -639,7 +639,7 @@ SpeakerSR::SpeakerSR() {
_newSceneNumber = 2811;
_textPos = Common::Point(10, 30);
_color1 = 13;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void SpeakerSR::setText(const Common::String &msg) {
@@ -680,7 +680,7 @@ SpeakerSL::SpeakerSL() {
_textPos = Common::Point(140, 30);
_textWidth = 160;
_color1 = 13;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void SpeakerSL::setText(const Common::String &msg) {
@@ -712,7 +712,7 @@ SpeakerQR::SpeakerQR() {
_newSceneNumber = 2611;
_textPos = Common::Point(10, 30);
_color1 = 13;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void SpeakerQR::setText(const Common::String &msg) {
@@ -744,7 +744,7 @@ SpeakerQU::SpeakerQU() {
_newSceneNumber = 7020;
_textPos = Common::Point(160, 30);
_color1 = 35;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void SpeakerQU::setText(const Common::String &msg) {
@@ -833,7 +833,7 @@ SpeakerSAL::SpeakerSAL() {
_newSceneNumber = 2851;
_textPos = Common::Point(10, 30);
_color1 = 13;
- _textMode = ALIGN_CENTRE;
+ _textMode = ALIGN_CENTER;
}
void SpeakerSAL::setText(const Common::String &msg) {
diff --git a/engines/tsage/ringworld_scenes1.cpp b/engines/tsage/ringworld_scenes1.cpp
index 7b9c315721..1fc6ab875d 100644
--- a/engines/tsage/ringworld_scenes1.cpp
+++ b/engines/tsage/ringworld_scenes1.cpp
@@ -605,7 +605,7 @@ void Scene20::postInit(SceneObjectList *OwnerList) {
setAction(&_action4);
}
- _sceneBounds.centre(_globals->_player._position.x, _globals->_player._position.y);
+ _sceneBounds.center(_globals->_player._position.x, _globals->_player._position.y);
}
_globals->_player.disableControl();
@@ -2397,7 +2397,7 @@ void Scene60::signal() {
_globals->_events.setCursor(CURSOR_USE);
_gfxButton.setText(EXIT_MSG);
- _gfxButton._bounds.centre(160, 193);
+ _gfxButton._bounds.center(160, 193);
_gfxButton.draw();
_gfxButton._bounds.expandPanes();
} else {
diff --git a/engines/tsage/ringworld_scenes10.cpp b/engines/tsage/ringworld_scenes10.cpp
index 56d6bd9101..2908667ca0 100644
--- a/engines/tsage/ringworld_scenes10.cpp
+++ b/engines/tsage/ringworld_scenes10.cpp
@@ -1228,7 +1228,7 @@ void Scene9700::signal() {
case 9701:
case 9702:
_gfxButton1.setText(EXIT_MSG);
- _gfxButton1._bounds.centre(50, 190);
+ _gfxButton1._bounds.center(50, 190);
_gfxButton1.draw();
_gfxButton1._bounds.expandPanes();
_globals->_player.enableControl();
@@ -1702,7 +1702,7 @@ void Scene9900::strAction2::signal() {
_txtArray1Index = (_txtArray1Index + 1) % 2;
}
_var3 = 1;
- _txtArray1[_txtArray1Index]._textMode = ALIGN_CENTRE;
+ _txtArray1[_txtArray1Index]._textMode = ALIGN_CENTER;
_txtArray1[_txtArray1Index]._width = 240;
_txtArray1[_txtArray1Index]._fontNumber = 2;
_txtArray1[_txtArray1Index]._color1 = 7;
@@ -1717,7 +1717,7 @@ void Scene9900::strAction2::signal() {
Common::Point pt2(_txtArray1[_txtArray1Index]._position.x, 100);
_txtArray1[_txtArray1Index].addMover(mover2, &pt2, 0);
- _txtArray2[_txtArray1Index]._textMode = ALIGN_CENTRE;
+ _txtArray2[_txtArray1Index]._textMode = ALIGN_CENTER;
_txtArray2[_txtArray1Index]._width = 240;
_txtArray2[_txtArray1Index]._fontNumber = 2;
_txtArray2[_txtArray1Index]._color1 = 23;
@@ -2048,7 +2048,7 @@ void Scene9999::postInit(SceneObjectList *OwnerList) {
else
setAction(&_action1);
- _globals->_sceneManager._scene->_sceneBounds.centre(_globals->_player._position.x, _globals->_player._position.y);
+ _globals->_sceneManager._scene->_sceneBounds.center(_globals->_player._position.x, _globals->_player._position.y);
_globals->_sceneManager._scene->_sceneBounds.contain(_globals->_sceneManager._scene->_backgroundBounds);
_globals->_sceneOffset.x = (_globals->_sceneManager._scene->_sceneBounds.left / 160) * 160;
diff --git a/engines/tsage/ringworld_scenes2.cpp b/engines/tsage/ringworld_scenes2.cpp
index c0b2fbb966..1fc45d323d 100644
--- a/engines/tsage/ringworld_scenes2.cpp
+++ b/engines/tsage/ringworld_scenes2.cpp
@@ -266,7 +266,7 @@ void Scene1000::postInit(SceneObjectList *OwnerList) {
setAction(&_action2);
- _globals->_sceneManager._scene->_sceneBounds.centre(_object1._position.x, _object1._position.y);
+ _globals->_sceneManager._scene->_sceneBounds.center(_object1._position.x, _object1._position.y);
_globals->_sceneManager._scene->_sceneBounds.contain(_globals->_sceneManager._scene->_backgroundBounds);
_globals->_sceneOffset.x = (_globals->_sceneManager._scene->_sceneBounds.left / 160) * 160;
@@ -280,7 +280,7 @@ void Scene1000::postInit(SceneObjectList *OwnerList) {
_object1._moveDiff = Common::Point(2, 2);
_object1.setPosition(Common::Point(120, 180));
- _globals->_sceneManager._scene->_sceneBounds.centre(_object1._position.x, _object1._position.y);
+ _globals->_sceneManager._scene->_sceneBounds.center(_object1._position.x, _object1._position.y);
_globals->_sceneManager._scene->_sceneBounds.contain(_globals->_sceneManager._scene->_backgroundBounds);
_globals->_sceneOffset.x = (_globals->_sceneManager._scene->_sceneBounds.left / 160) * 160;
@@ -301,7 +301,7 @@ void Scene1000::postInit(SceneObjectList *OwnerList) {
_globals->_player.hide();
_globals->_player.disableControl();
- _globals->_sceneManager._scene->_sceneBounds.centre(_object3._position.x, _object3._position.y);
+ _globals->_sceneManager._scene->_sceneBounds.center(_object3._position.x, _object3._position.y);
setAction(&_action3);
}
@@ -776,7 +776,7 @@ void Scene1400::postInit(SceneObjectList *OwnerList) {
_globals->_player._moveDiff = Common::Point(4, 2);
_globals->_player.setPosition(Common::Point(160, 800));
- _globals->_sceneManager._scene->_sceneBounds.centre(_globals->_player._position);
+ _globals->_sceneManager._scene->_sceneBounds.center(_globals->_player._position);
_globals->_sceneManager._scene->_sceneBounds.contain(_globals->_sceneManager._scene->_backgroundBounds);
_globals->_sceneOffset.y = (_globals->_sceneManager._scene->_sceneBounds.top / 100) * 100;
diff --git a/engines/tsage/ringworld_scenes3.cpp b/engines/tsage/ringworld_scenes3.cpp
index 6895c3b669..0cf299c2de 100644
--- a/engines/tsage/ringworld_scenes3.cpp
+++ b/engines/tsage/ringworld_scenes3.cpp
@@ -3118,7 +3118,7 @@ void Scene2222::postInit(SceneObjectList *OwnerList) {
}
_soundHandler.startSound(116);
- _globals->_sceneManager._scene->_sceneBounds.centre(_hotspot1._position);
+ _globals->_sceneManager._scene->_sceneBounds.center(_hotspot1._position);
_globals->_sceneManager._scene->_sceneBounds.contain(_globals->_sceneManager._scene->_backgroundBounds);
_globals->_sceneOffset.x = (_globals->_sceneManager._scene->_sceneBounds.left / 160) * 160;
@@ -4875,7 +4875,7 @@ void Scene2310::signal() {
Common::String msg = Common::String::format(fmtString.c_str(), _pageList[_pageIndex]._pageNumber);
_sceneText._width = 280;
- _sceneText._textMode = ALIGN_CENTRE;
+ _sceneText._textMode = ALIGN_CENTER;
_sceneText._color1 = 35;
_sceneText._fontNumber = 2;
_sceneText.setup(msg);
@@ -5971,7 +5971,7 @@ void Scene2320::postInit(SceneObjectList *OwnerList) {
}
_globals->_stripNum = 0;
- _globals->_sceneManager._scene->_sceneBounds.centre(_globals->_player._position);
+ _globals->_sceneManager._scene->_sceneBounds.center(_globals->_player._position);
loadScene(2320);
_hotspot14._sceneRegionId = 8;
@@ -6088,7 +6088,7 @@ void Scene2400::postInit(SceneObjectList *OwnerList) {
setAction(&_action1);
- _globals->_sceneManager._scene->_sceneBounds.centre(_globals->_player._position.x, _globals->_player._position.y);
+ _globals->_sceneManager._scene->_sceneBounds.center(_globals->_player._position.x, _globals->_player._position.y);
_globals->_sceneManager._scene->_sceneBounds.contain(_globals->_sceneManager._scene->_backgroundBounds);
_globals->_sceneOffset.x = (_globals->_sceneManager._scene->_sceneBounds.left / 160) * 160;
diff --git a/engines/tsage/ringworld_scenes5.cpp b/engines/tsage/ringworld_scenes5.cpp
index de29a1cefc..d945bec522 100644
--- a/engines/tsage/ringworld_scenes5.cpp
+++ b/engines/tsage/ringworld_scenes5.cpp
@@ -1594,7 +1594,7 @@ void Scene4025::signal() {
if (_sceneMode != 4027) {
if (_sceneMode != 4028) {
_gfxButton.setText(EXIT_MSG);
- _gfxButton._bounds.centre(144, 107);
+ _gfxButton._bounds.center(144, 107);
_gfxButton.draw();
_gfxButton._bounds.expandPanes();
}
@@ -4108,7 +4108,7 @@ void Scene4300::signal() {
_hotspot14.setPosition(Common::Point(60, 199));
_gfxButton.setText(EXIT_MSG);
- _gfxButton._bounds.centre(60, 193);
+ _gfxButton._bounds.center(60, 193);
_gfxButton.draw();
_gfxButton._bounds.expandPanes();
diff --git a/engines/tsage/ringworld_scenes6.cpp b/engines/tsage/ringworld_scenes6.cpp
index 3ea4d7b279..5fdb09732a 100644
--- a/engines/tsage/ringworld_scenes6.cpp
+++ b/engines/tsage/ringworld_scenes6.cpp
@@ -1277,7 +1277,7 @@ void Scene5100::postInit(SceneObjectList *OwnerList) {
_hotspot15.setPosition(Common::Point(977, 173));
_hotspot15.setPriority2(1);
- _globals->_sceneManager._scene->_sceneBounds.centre(_globals->_player._position);
+ _globals->_sceneManager._scene->_sceneBounds.center(_globals->_player._position);
loadScene(5100);
_globals->_soundHandler.startSound(205);
}
@@ -1703,7 +1703,7 @@ void Scene5200::postInit(SceneObjectList *OwnerList) {
_hotspot10._sceneRegionId = 9;
_globals->_sceneItems.addItems(&_hotspot12, &_hotspot13, &_hotspot9, &_hotspot10, &_hotspot11, NULL);
- _globals->_sceneManager._scene->_sceneBounds.centre(_globals->_player._position);
+ _globals->_sceneManager._scene->_sceneBounds.center(_globals->_player._position);
loadScene(5200);
}
diff --git a/engines/tsage/ringworld_scenes8.cpp b/engines/tsage/ringworld_scenes8.cpp
index e437662774..a2742bea25 100644
--- a/engines/tsage/ringworld_scenes8.cpp
+++ b/engines/tsage/ringworld_scenes8.cpp
@@ -1578,7 +1578,7 @@ void Scene7600::postInit(SceneObjectList *OwnerList) {
_globals->_player.setPosition(Common::Point(-50, 195));
setAction(&_action1);
}
- _sceneBounds.centre(_globals->_player._position.x, _globals->_player._position.y);
+ _sceneBounds.center(_globals->_player._position.x, _globals->_player._position.y);
loadScene(7600);
_soundHandler2.startSound(255);
_soundHandler1.startSound(251);
@@ -2045,7 +2045,7 @@ void Scene7700::Object8::doAction(int action) {
scene->_object14.setPosition(Common::Point(139, 151), 0);
scene->_gfxButton.setText(EXIT_MSG);
- scene->_gfxButton._bounds.centre(140, 189);
+ scene->_gfxButton._bounds.center(140, 189);
scene->_gfxButton.draw();
scene->_gfxButton._bounds.expandPanes();
@@ -2059,7 +2059,7 @@ void Scene7700::Object8::doAction(int action) {
scene->_object15.setPriority2(200);
scene->_gfxButton.setText(EXIT_MSG);
- scene->_gfxButton._bounds.centre(140, 186);
+ scene->_gfxButton._bounds.center(140, 186);
scene->_gfxButton.draw();
scene->_gfxButton._bounds.expandPanes();
diff --git a/engines/tsage/tsage.h b/engines/tsage/tsage.h
index 2a627d80bc..25a99f094b 100644
--- a/engines/tsage/tsage.h
+++ b/engines/tsage/tsage.h
@@ -61,8 +61,8 @@ struct tSageGameDescription;
#define SCREEN_WIDTH 320
#define SCREEN_HEIGHT 200
-#define SCREEN_CENTRE_X 160
-#define SCREEN_CENTRE_Y 100
+#define SCREEN_CENTER_X 160
+#define SCREEN_CENTER_Y 100
class TSageEngine : public Engine {
private:
diff --git a/engines/tsage/dialogs.cpp b/engines/tsage/dialogs.cpp
index b76d60ac48..0778ea8b2b 100644
--- a/engines/tsage/dialogs.cpp
+++ b/engines/tsage/dialogs.cpp
@@ -64,8 +64,8 @@ MessageDialog::MessageDialog(const Common::String &message, const Common::String
// Do post setup for the dialog
setDefaults();
- // Set the dialog's centre
- setCentre(_globals->_dialogCentre.x, _globals->_dialogCentre.y);
+ // Set the dialog's center
+ setCenter(_globals->_dialogCenter.x, _globals->_dialogCenter.y);
}
int MessageDialog::show(const Common::String &message, const Common::String &btn1Message, const Common::String &btn2Message) {
@@ -167,7 +167,7 @@ RightClickDialog::RightClickDialog() : GfxDialog(),
// Set the dialog position
dialogRect.resize(_surface, 0, 0, 100);
- dialogRect.centre(_globals->_events._mousePos.x, _globals->_events._mousePos.y);
+ dialogRect.center(_globals->_events._mousePos.x, _globals->_events._mousePos.y);
// Ensure the dialog will be entirely on-screen
Rect screenRect = _globals->gfxManager()._bounds;
@@ -457,7 +457,7 @@ InventoryDialog::InventoryDialog(bool allFlag) {
addElements(&_btnLook, &_btnOk, NULL);
frame();
- setCentre(SCREEN_CENTRE_X, SCREEN_CENTRE_Y);
+ setCenter(SCREEN_CENTER_X, SCREEN_CENTER_Y);
}
void InventoryDialog::execute() {
@@ -591,7 +591,7 @@ OptionsDialog::OptionsDialog() {
// Set the dialog size and position
frame();
- setCentre(160, 100);
+ setCenter(160, 100);
}
diff --git a/engines/tsage/graphics.cpp b/engines/tsage/graphics.cpp
index 0dbb48eb63..5b6cd196b2 100644
--- a/engines/tsage/graphics.cpp
+++ b/engines/tsage/graphics.cpp
@@ -147,22 +147,22 @@ void Rect::collapse(int dx, int dy) {
}
/**
- * Centres the rectangle at a given position
+ * Centers the rectangle at a given position
*
* @xp x position for new centre
* @yp y position for new centre
*/
-void Rect::centre(int xp, int yp) {
+void Rect::center(int xp, int yp) {
moveTo(xp - (width() / 2), yp - (height() / 2));
}
/**
* Centres the rectangle at the centre of a second passed rectangle
*
* @r Second rectangle whose centre to use
*/
-void Rect::centre(const Rect &r) {
- centre(r.left + (r.width() / 2), r.top + (r.height() / 2));
+void Rect::center(const Rect &r) {
+ center(r.left + (r.width() / 2), r.top + (r.height() / 2));
}
/*
@@ -355,7 +355,7 @@ bool GfxSurface::displayText(const Common::String &msg, const Common::Point &pt)
// Get the area for text display
Rect textRect;
gfxManager.getStringBounds(msg.c_str(), textRect, 200);
- textRect.centre(pt.x, pt.y);
+ textRect.center(pt.x, pt.y);
// Make a backup copy of the area the text will occupy
Rect saveRect = textRect;
@@ -798,7 +798,7 @@ void GfxButton::draw() {
// Display the button's text
Rect tempRect(_bounds);
tempRect.collapse(3, 3);
- gfxManager._font.writeLines(_message.c_str(), tempRect, ALIGN_CENTRE);
+ gfxManager._font.writeLines(_message.c_str(), tempRect, ALIGN_CENTER);
gfxManager.unlockSurface();
}
@@ -928,7 +928,7 @@ void GfxDialog::setTopLeft(int xp, int yp) {
_bounds.moveTo(xp - 6, yp - 6);
}
-void GfxDialog::setCentre(int xp, int yp) {
+void GfxDialog::setCenter(int xp, int yp) {
setTopLeft(xp - (_bounds.width() / 2), yp - (_bounds.height() / 2));
}
@@ -1355,7 +1355,7 @@ void GfxFont::writeLines(const char *s, const Rect &bounds, TextAlign align) {
writeString(s, numChars);
break;
- case ALIGN_CENTRE:
+ case ALIGN_CENTER:
// Center aligned text
_position.x = bounds.left + (bounds.width() / 2) - (getStringWidth(s, numChars) / 2);
writeString(s, numChars);
@@ -147,22 +147,22 @@ void Rect::collapse(int dx, int dy) {
*
- * @xp x position for new centre
- * @yp y position for new centre
+ * @xp x position for new center
+ * @yp y position for new center
*/
@@ -147,22 +147,22 @@ void Rect::collapse(int dx, int dy) {
}
/**
- * Centres the rectangle at the centre of a second passed rectangle
+ * Centers the rectangle at the center of a second passed rectangle
*
@@ -147,22 +147,22 @@ void Rect::collapse(int dx, int dy) {
*
- * @r Second rectangle whose centre to use
+ * @r Second rectangle whose center to use
*/